# eric7.Project.NewDialogClassDialog

Module implementing a dialog to enter the data for a new dialog class file.

### Global Attributes

None

### Classes

NewDialogClassDialog | Class implementing a dialog to ente the data for a new dialog class file.

### Functions

None

## NewDialogClassDialog

Class implementing a dialog to ente the data for a new dialog class file.

### Derived from

QDialog, Ui_NewDialogClassDialog

### Class Attributes

None

### Class Methods

None

### Methods

NewDialogClassDialog | Constructor
__enableOkButton | Private slot to set the enable state of theok button.
getData | Public method to retrieve the data entered into the dialog.
on_classnameEdit_textChanged | Private slot called, when thext of the classname edit has changed.
on_filenameEdit_textChanged | Private slot called, when thext of the filename edit has changed.
on_pathnamePicker_textChanged | Private slot called, when the text of the path name has changed.

### Static Methods

None

#### NewDialogClassDialog (Constructor)

NewDialogClassDialog(defaultClassName, defaultFile, defaultPath, parent=None)

Constructor

defaultClassName (str)
  proposed name for the new class
defaultFile (str)
  proposed name for the source file
defaultPath (str)
  default path for the new file
parent (QWidget)
  parent widget if the dialog

#### NewDialogClassDialog.__enableOkButton

__enableOkButton()

Private slot to set the enable state of theok button.

#### NewDialogClassDialog.getData

getData()

Public method to retrieve the data entered into the dialog.

Return:
  tuple giving the classname and the file name

Return Type:
  tuple of (str, str)

#### NewDialogClassDialog.on_classnameEdit_textChanged

on_classnameEdit_textChanged(text)

Private slot called, when thext of the classname edit has changed.

text (str)
  changed text

#### NewDialogClassDialog.on_filenameEdit_textChanged

on_filenameEdit_textChanged(text)

Private slot called, when thext of the filename edit has changed.

text (str)
  changed text

#### NewDialogClassDialog.on_pathnamePicker_textChanged

on_pathnamePicker_textChanged(text)

Private slot called, when the text of the path name has changed.

text (str)
  changed text

Up